---
title: "Lisp for Web-Based Applications"
---

After a link to [Beating the Averages](avg.html) was posted on slashdot, some readers wanted to hear in more detail about the specific technical advantages we got from using Lisp in Viaweb. For those who are interested, here are some excerpts from a talk I gave in April 2001 at BBN Labs in Cambridge, MA.

[BBN Talk Excerpts (ASCII)](https://sep.yimg.com/ty/cdn/paulgraham/bbnexcerpts.txt?t=1595850613&)